@@ -25,6 +25,10 @@
 	#include <config.h>
 #endif
 
+#ifndef HAVE_X11
+#error file should only be built when HAVE_X11 is enabled
+#endif
+
 #include <glib/gi18n.h>
 
 #include <gtk/gtk.h>
@@ -490,18 +494,14 @@ static void display_about_dialog(GtkAction* action, ShowDesktopData* sdd)
 		NULL
 	};
 
-	/* Translator credits */
-	//const char* translator_credits = _("translator-credits");
-	char copyright[] = \
-		"Copyright \xc2\xa9 2012-2018 MATE developers\n"
-		"Copyright \xc2\xa9 2011 Perberos\n"
-		"Copyright \xc2\xa9 2002 Red Hat, Inc.";
-
 	gtk_show_about_dialog(GTK_WINDOW(sdd->applet),
 		"program-name", _("Show Desktop Button"),
+		"title", _("About Show Desktop Button"),
 		"authors", authors,
 		"comments", _("This button lets you hide all windows and show the desktop."),
-		"copyright", copyright,
+		"copyright", _("Copyright \xc2\xa9 2002 Red Hat, Inc.\n"
+		               "Copyright \xc2\xa9 2011 Perberos\n"
+                               "Copyright \xc2\xa9 2012-2020 MATE developers"),
 		"documenters", documenters,
 		"icon-name", SHOW_DESKTOP_ICON,
 		"logo-icon-name", SHOW_DESKTOP_ICON,
