@@ -22,6 +22,9 @@
 #define WNCK_I_KNOW_THIS_IS_UNSTABLE
 #include <libwnck/libwnck.h>
 #include <gio/gio.h>
+#ifdef HAVE_WINDOW_PREVIEWS
+#include <gdk/gdkx.h>
+#endif
 
 #define MATE_DESKTOP_USE_UNSTABLE_API
 #include <libmate-desktop/mate-desktop-utils.h>
@@ -31,11 +34,19 @@
 
 #define WINDOW_LIST_ICON "mate-panel-window-list"
 #define WINDOW_LIST_SCHEMA "org.mate.panel.applet.window-list"
+#ifdef HAVE_WINDOW_PREVIEWS
+#define WINDOW_LIST_PREVIEW_SCHEMA "org.mate.panel.applet.window-list-previews"
+#endif
 
 typedef struct {
 	GtkWidget* applet;
 	GtkWidget* tasklist;
+#ifdef HAVE_WINDOW_PREVIEWS
+	GtkWidget* preview;
 
+	gboolean show_window_thumbnails;
+	gint thumbnail_size;
+#endif
 	gboolean include_all_workspaces;
 	WnckTasklistGroupingType grouping;
 	gboolean move_unminimized_windows;
@@ -52,6 +63,11 @@ typedef struct {
 	GtkWidget* properties_dialog;
 	GtkWidget* show_current_radio;
 	GtkWidget* show_all_radio;
+#ifdef HAVE_WINDOW_PREVIEWS
+	GtkWidget* show_thumbnails_radio;
+	GtkWidget* hide_thumbnails_radio;
+	GtkWidget* thumbnail_size_spin;
+#endif
 	GtkWidget* never_group_radio;
 	GtkWidget* auto_group_radio;
 	GtkWidget* always_group_radio;
@@ -60,6 +76,9 @@ typedef struct {
 	GtkWidget* change_workspace_radio;
 
 	GSettings* settings;
+#ifdef HAVE_WINDOW_PREVIEWS
+	GSettings* preview_settings;
+#endif
 } TasklistData;
 
 static void call_system_monitor(GtkAction* action, TasklistData* tasklist);
@@ -139,6 +158,173 @@ static void applet_change_background(MatePanelApplet* applet, MatePanelAppletBac
 	}
 }
 
+#ifdef HAVE_WINDOW_PREVIEWS
+static GdkPixbuf *preview_window_thumbnail (WnckWindow *wnck_window, TasklistData *tasklist)
+{
+	GdkWindow *window;
+	GdkPixbuf *screenshot;
+	GdkPixbuf *thumbnail;
+	guchar *pixels;
+	double ratio;
+	int width, height;
+	int scale;
+
+	window = gdk_x11_window_foreign_new_for_display (gdk_display_get_default (), wnck_window_get_xid (wnck_window));
+
+	if (window == NULL)
+		return NULL;
+
+	scale = gdk_window_get_scale_factor (window);
+	width = gdk_window_get_width (window) * scale;
+	height = gdk_window_get_height (window) * scale;
+
+	/* Generate window screenshot for preview */
+	screenshot = gdk_pixbuf_get_from_window (window, 0, 0, width / scale, height / scale);
+	g_object_unref (window);
+
+	if (screenshot == NULL)
+		return NULL;
+
+	/* Determine whether the contents of the screenshot are empty */
+	pixels = gdk_pixbuf_get_pixels (screenshot);
+	if (!g_strcmp0 ((const char *)pixels, ""))
+	{
+		g_object_unref (screenshot);
+		return NULL;
+	}
+
+	/* Scale to configured size while maintaining aspect ratio */
+	if (width > height)
+	{
+		ratio = (double) height / (double) width;
+		width = MIN(width, tasklist->thumbnail_size);
+		height = width * ratio;
+	}
+	else
+	{
+		ratio = (double) width / (double) height;
+		height = MIN(height, tasklist->thumbnail_size);
+		width = height * ratio;
+	}
+
+	thumbnail = gdk_pixbuf_scale_simple (screenshot, width, height, GDK_INTERP_BILINEAR);
+	g_object_unref (screenshot);
+
+	return thumbnail;
+}
+
+#define PREVIEW_PADDING 5
+static void preview_window_reposition (TasklistData *tasklist, GdkPixbuf *thumbnail)
+{
+	GdkMonitor *monitor;
+	GdkRectangle monitor_geom;
+	int x_pos, y_pos;
+	int width, height;
+
+	width = gdk_pixbuf_get_width (thumbnail);
+	height = gdk_pixbuf_get_height (thumbnail);
+
+	/* Resize window to fit thumbnail */
+	gtk_window_resize (GTK_WINDOW (tasklist->preview), width, height);
+
+	/* Set position at pointer, then re-adjust from there to just outside of the pointer */
+	gtk_window_set_position (GTK_WINDOW (tasklist->preview), GTK_WIN_POS_MOUSE);
+	gtk_window_get_position (GTK_WINDOW (tasklist->preview), &x_pos, &y_pos);
+
+	/* Get geometry of monitor where tasklist is located to calculate correct position of preview */
+	monitor = gdk_display_get_monitor_at_point (gdk_display_get_default (), x_pos, y_pos);
+	gdk_monitor_get_geometry (monitor, &monitor_geom);
+
+	/* Add padding to clear the panel */
+	switch (mate_panel_applet_get_orient (MATE_PANEL_APPLET (tasklist->applet)))
+	{
+		case MATE_PANEL_APPLET_ORIENT_LEFT:
+			x_pos = monitor_geom.width + monitor_geom.x - (width + tasklist->size) - PREVIEW_PADDING;
+			break;
+		case MATE_PANEL_APPLET_ORIENT_RIGHT:
+			x_pos = tasklist->size + PREVIEW_PADDING;
+			break;
+		case MATE_PANEL_APPLET_ORIENT_UP:
+			y_pos = monitor_geom.height + monitor_geom.y - (height + tasklist->size) - PREVIEW_PADDING;
+			break;
+		case MATE_PANEL_APPLET_ORIENT_DOWN:
+		default:
+			y_pos = tasklist->size + PREVIEW_PADDING;
+			break;
+	}
+
+	gtk_window_move (GTK_WINDOW (tasklist->preview), x_pos, y_pos);
+}
+
+static gboolean preview_window_draw (GtkWidget *widget, cairo_t *cr, GdkPixbuf *thumbnail)
+{
+	GtkStyleContext *context;
+
+	context = gtk_widget_get_style_context (widget);
+	gtk_render_icon (context, cr, thumbnail, 0, 0);
+
+	return FALSE;
+}
+
+static gboolean applet_enter_notify_event (WnckTasklist *tl, GList *wnck_windows, TasklistData *tasklist)
+{
+	GdkPixbuf *thumbnail;
+	WnckWindow *wnck_window = NULL;
+	int n_windows;
+
+	if (tasklist->preview != NULL)
+	{
+		gtk_widget_destroy (tasklist->preview);
+		tasklist->preview = NULL;
+	}
+
+	if (!tasklist->show_window_thumbnails || wnck_windows == NULL)
+		return FALSE;
+
+	n_windows = g_list_length (wnck_windows);
+	/* TODO: Display a list of stacked thumbnails for grouped windows. */
+	if (n_windows == 1)
+	{
+		GList* l = wnck_windows;
+		if (l != NULL)
+			wnck_window = (WnckWindow*)l->data;
+	}
+
+	if (wnck_window == NULL)
+		return FALSE;
+
+	thumbnail = preview_window_thumbnail (wnck_window, tasklist);
+
+	if (thumbnail == NULL)
+		return FALSE;
+
+	/* Create window to display preview */
+	tasklist->preview = gtk_window_new (GTK_WINDOW_POPUP);
+
+	gtk_widget_set_app_paintable (tasklist->preview, TRUE);
+	gtk_window_set_resizable (GTK_WINDOW (tasklist->preview), TRUE);
+
+	preview_window_reposition (tasklist, thumbnail);
+
+	gtk_widget_show (tasklist->preview);
+
+	g_signal_connect_data (G_OBJECT (tasklist->preview), "draw", G_CALLBACK (preview_window_draw), thumbnail, (GClosureNotify) g_object_unref, 0);
+
+	return FALSE;
+}
+
+static gboolean applet_leave_notify_event (WnckTasklist *tl, GList *wnck_windows, TasklistData *tasklist)
+{
+	if (tasklist->preview != NULL)
+	{
+		gtk_widget_destroy (tasklist->preview);
+		tasklist->preview = NULL;
+	}
+
+	return FALSE;
+}
+#endif
+
 static void applet_change_pixel_size(MatePanelApplet* applet, gint size, TasklistData* tasklist)
 {
 	if (tasklist->size == size)
@@ -227,6 +413,57 @@ static void display_all_workspaces_changed(GSettings* settings, gchar* key, Task
 	tasklist_properties_update_content_radio(tasklist);
 }
 
+#ifdef HAVE_WINDOW_PREVIEWS
+static void tasklist_update_thumbnails_radio(TasklistData* tasklist)
+{
+	GtkWidget* button;
+
+	if (tasklist->show_thumbnails_radio == NULL || tasklist->hide_thumbnails_radio == NULL)
+		return;
+
+	if (tasklist->show_window_thumbnails)
+	{
+		button = tasklist->show_thumbnails_radio;
+	}
+	else
+	{
+		button = tasklist->hide_thumbnails_radio;
+	}
+
+	if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button)))
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
+}
+
+static void window_thumbnails_changed(GSettings *settings, gchar* key, TasklistData* tasklist)
+{
+	gboolean value;
+
+	value = g_settings_get_boolean(settings, key);
+
+	tasklist->show_window_thumbnails = (value != 0);
+
+	tasklist_update_thumbnails_radio(tasklist);
+}
+
+static void tasklist_update_thumbnail_size_spin(TasklistData* tasklist)
+{
+	GtkWidget* button;
+
+	if (!tasklist->thumbnail_size)
+		return;
+
+	button = tasklist->thumbnail_size_spin;
+
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(button), (gdouble)tasklist->thumbnail_size);
+}
+
+static void thumbnail_size_changed(GSettings *settings, gchar* key, TasklistData* tasklist)
+{
+	tasklist->thumbnail_size = g_settings_get_int(settings, key);
+	tasklist_update_thumbnail_size_spin(tasklist);
+}
+#endif
+
 static GtkWidget* get_grouping_button(TasklistData* tasklist, WnckTasklistGroupingType type)
 {
 	switch (type)
@@ -303,6 +540,19 @@ static void setup_gsettings(TasklistData* tasklist)
 					  "changed::display-all-workspaces",
 					  G_CALLBACK (display_all_workspaces_changed),
 					  tasklist);
+
+#ifdef HAVE_WINDOW_PREVIEWS
+	tasklist->preview_settings = mate_panel_applet_settings_new (MATE_PANEL_APPLET (tasklist->applet), WINDOW_LIST_PREVIEW_SCHEMA);
+
+	g_signal_connect (tasklist->preview_settings,
+					  "changed::show-window-thumbnails",
+					  G_CALLBACK (window_thumbnails_changed),
+					  tasklist);
+	g_signal_connect (tasklist->preview_settings,
+					  "changed::thumbnail-window-size",
+					  G_CALLBACK (thumbnail_size_changed),
+					  tasklist);
+#endif
 	g_signal_connect (tasklist->settings,
 					  "changed::group-windows",
 					  G_CALLBACK (group_windows_changed),
@@ -421,6 +671,12 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 
 	tasklist->include_all_workspaces = g_settings_get_boolean (tasklist->settings, "display-all-workspaces");
 
+#ifdef HAVE_WINDOW_PREVIEWS
+	tasklist->show_window_thumbnails = g_settings_get_boolean (tasklist->preview_settings, "show-window-thumbnails");
+
+	tasklist->thumbnail_size = g_settings_get_int (tasklist->preview_settings, "thumbnail-window-size");
+#endif
+
 	tasklist->grouping = g_settings_get_enum (tasklist->settings, "group-windows");
 
 	tasklist->move_unminimized_windows = g_settings_get_boolean (tasklist->settings, "move-unminimized-windows");
@@ -451,6 +707,10 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 	wnck_tasklist_set_icon_loader(WNCK_TASKLIST(tasklist->tasklist), icon_loader_func, tasklist, NULL);
 
 	g_signal_connect(G_OBJECT(tasklist->tasklist), "destroy", G_CALLBACK(destroy_tasklist), tasklist);
+#ifdef HAVE_WINDOW_PREVIEWS
+	g_signal_connect(G_OBJECT(tasklist->tasklist), "task_enter_notify", G_CALLBACK(applet_enter_notify_event), tasklist);
+	g_signal_connect(G_OBJECT(tasklist->tasklist), "task_leave_notify", G_CALLBACK(applet_leave_notify_event), tasklist);
+#endif
 
 	g_signal_connect(G_OBJECT(tasklist->applet), "size_allocate", G_CALLBACK(applet_size_allocate), tasklist);
 
@@ -476,23 +736,23 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 	for (i = 0; i < G_N_ELEMENTS(system_monitors); i += 1)
 	{
 		programpath = g_find_program_in_path(system_monitors[i]);
-		
+
 		if (programpath != NULL)
 		{
 			g_free(programpath);
 			/* we give up */
 			goto _system_monitor_found;
 		}
-		
+
 		/* search another */
 	}
 
 	/* system monitor not found */
 	gtk_action_set_visible(gtk_action_group_get_action(action_group, "TasklistSystemMonitor"), FALSE);
-	
+
 	_system_monitor_found:;
 	/* end of system monitor item */
-	
+
 
 	mate_panel_applet_setup_menu_from_resource (MATE_PANEL_APPLET (tasklist->applet),
 	                                            WNCKLET_RESOURCE_PATH "window-list-menu.xml",
@@ -564,7 +824,7 @@ static void display_about_dialog(GtkAction* action, TasklistData* tasklist)
 		"comments", _("The Window List shows a list of all windows in a set of buttons and lets you browse them."),
 		"copyright", _("Copyright \xc2\xa9 2002 Red Hat, Inc.\n"
 		               "Copyright \xc2\xa9 2011 Perberos\n"
-		               "Copyright \xc2\xa9 2012-2019 MATE developers"),
+		               "Copyright \xc2\xa9 2012-2020 MATE developers"),
 		"documenters", documenters,
 		"icon-name", WINDOW_LIST_ICON,
 		"logo-icon-name", WINDOW_LIST_ICON,
@@ -584,6 +844,18 @@ static void group_windows_toggled(GtkToggleButton* button, TasklistData* tasklis
 	}
 }
 
+#ifdef HAVE_WINDOW_PREVIEWS
+static void show_thumbnails_toggled(GtkToggleButton* button, TasklistData* tasklist)
+{
+	g_settings_set_boolean(tasklist->preview_settings, "show-window-thumbnails", gtk_toggle_button_get_active(button));
+}
+
+static void thumbnail_size_spin_changed(GtkSpinButton* button, TasklistData* tasklist)
+{
+	g_settings_set_int(tasklist->preview_settings, "thumbnail-window-size", gtk_spin_button_get_value_as_int(button));
+}
+#endif
+
 static void move_minimized_toggled(GtkToggleButton* button, TasklistData* tasklist)
 {
 	g_settings_set_boolean(tasklist->settings, "move-unminimized-windows", gtk_toggle_button_get_active(button));
@@ -627,6 +899,9 @@ static void setup_sensitivity(TasklistData* tasklist, GtkBuilder* builder, const
 static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 {
 	GtkWidget* button;
+#ifdef HAVE_WINDOW_PREVIEWS
+	GtkAdjustment *adjustment;
+#endif
 
 	tasklist->show_current_radio = WID("show_current_radio");
 	tasklist->show_all_radio = WID("show_all_radio");
@@ -639,6 +914,21 @@ static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 
 	setup_sensitivity(tasklist, builder, "never_group_radio", "auto_group_radio", "always_group_radio", "group-windows" /* key */);
 
+#ifdef HAVE_WINDOW_PREVIEWS
+	tasklist->show_thumbnails_radio = WID("show_thumbnails_radio");
+	tasklist->hide_thumbnails_radio = WID("hide_thumbnails_radio");
+	tasklist->thumbnail_size_spin = WID("thumbnail_size_spin");
+
+	setup_sensitivity(tasklist, builder, "show_thumbnails_radio", "hide_thumbnails_radio", NULL, "show-window-thumbnails" /* key */);
+	gtk_widget_set_sensitive(tasklist->thumbnail_size_spin, TRUE);
+	adjustment = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON(tasklist->thumbnail_size_spin));
+	gtk_adjustment_set_lower (adjustment, 0);
+	gtk_adjustment_set_upper (adjustment, 999);
+	gtk_adjustment_set_step_increment (adjustment, 1);
+#else
+	gtk_widget_hide(WID("window_thumbnails"));
+#endif
+
 	tasklist->minimized_windows_label = WID("minimized_windows_label");
 	tasklist->move_minimized_radio = WID("move_minimized_radio");
 	tasklist->change_workspace_radio = WID("change_workspace_radio");
@@ -656,6 +946,15 @@ static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 	g_signal_connect(G_OBJECT(tasklist->auto_group_radio), "toggled", (GCallback) group_windows_toggled, tasklist);
 	g_signal_connect(G_OBJECT(tasklist->always_group_radio), "toggled", (GCallback) group_windows_toggled, tasklist);
 
+#ifdef HAVE_WINDOW_PREVIEWS
+	/* show thumbnails on hover: */
+	tasklist_update_thumbnails_radio(tasklist);
+	g_signal_connect(G_OBJECT(tasklist->show_thumbnails_radio), "toggled", (GCallback) show_thumbnails_toggled, tasklist);
+	/* change thumbnail size: */
+	tasklist_update_thumbnail_size_spin(tasklist);
+	g_signal_connect(G_OBJECT(tasklist->thumbnail_size_spin), "value-changed", (GCallback) thumbnail_size_spin_changed, tasklist);
+#endif
+
 	/* move window when unminimizing: */
 	tasklist_update_unminimization_radio(tasklist);
 	g_signal_connect(G_OBJECT(tasklist->move_minimized_radio), "toggled", (GCallback) move_minimized_toggled, tasklist);
@@ -698,6 +997,12 @@ static void destroy_tasklist(GtkWidget* widget, TasklistData* tasklist)
 {
 	g_signal_handlers_disconnect_by_data (G_OBJECT (tasklist->applet), tasklist);
 
+#ifdef HAVE_WINDOW_PREVIEWS
+	g_signal_handlers_disconnect_by_data (G_OBJECT (tasklist->tasklist), tasklist);
+	g_signal_handlers_disconnect_by_data (tasklist->preview_settings, tasklist);
+	g_object_unref(tasklist->preview_settings);
+#endif
+
 	g_signal_handlers_disconnect_by_data (tasklist->settings, tasklist);
 
 	g_object_unref(tasklist->settings);
@@ -705,6 +1010,10 @@ static void destroy_tasklist(GtkWidget* widget, TasklistData* tasklist)
 	if (tasklist->properties_dialog)
 		gtk_widget_destroy(tasklist->properties_dialog);
 
-	g_free(tasklist);
+#ifdef HAVE_WINDOW_PREVIEWS
+	if (tasklist->preview)
+		gtk_widget_destroy(tasklist->preview);
+#endif
 
+	g_free(tasklist);
 }
