@@ -51,11 +51,8 @@
 #include "mate-panel-applet-marshal.h"
 #include "mate-panel-applet-enums.h"
 
-#define MATE_PANEL_APPLET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_APPLET, MatePanelAppletPrivate))
-
 struct _MatePanelAppletPrivate {
 	GtkWidget         *plug;
-	GtkWidget         *applet;
 	GDBusConnection   *connection;
 
 	gboolean           out_of_process;
@@ -153,7 +150,7 @@ static const GtkToggleActionEntry menu_toggle_entries[] = {
 	  G_CALLBACK (mate_panel_applet_menu_cmd_lock) }
 };
 
-G_DEFINE_TYPE (MatePanelApplet, mate_panel_applet, GTK_TYPE_EVENT_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (MatePanelApplet, mate_panel_applet, GTK_TYPE_EVENT_BOX)
 
 #define MATE_PANEL_APPLET_INTERFACE   "org.mate.panel.applet.Applet"
 #define MATE_PANEL_APPLET_OBJECT_PATH "/org/mate/panel/applet/%s/%d"
@@ -273,7 +270,7 @@ mate_panel_applet_size_hints_changed (MatePanelApplet *applet,
 }
 
 /**
- * mate_panel_applet_set_size_hints: 
+ * mate_panel_applet_set_size_hints:
  * @applet: applet
  * @size_hints: (array length=n_elements): List of integers
  * @n_elements: Length of @size_hints
@@ -849,16 +846,32 @@ mate_panel_applet_menu_popup (MatePanelApplet *applet,
 /* Fix any failures of compiz/other wm's to communicate with gtk for transparency */
 	GdkScreen *screen = gtk_widget_get_screen(GTK_WIDGET(toplevel));
 	GdkVisual *visual = gdk_screen_get_rgba_visual(screen);
-	gtk_widget_set_visual(GTK_WIDGET(toplevel), visual); 
+	gtk_widget_set_visual(GTK_WIDGET(toplevel), visual);
 /* Set menu and it's toplevel window to follow panel theme */
 	GtkStyleContext *context;
 	context = gtk_widget_get_style_context (GTK_WIDGET(toplevel));
 	gtk_style_context_add_class(context,"gnome-panel-menu-bar");
 	gtk_style_context_add_class(context,"mate-panel-menu-bar");
+	GdkGravity widget_anchor = GDK_GRAVITY_NORTH_WEST;
+	GdkGravity menu_anchor = GDK_GRAVITY_NORTH_WEST;
+	switch (applet->priv->orient) {
+	case MATE_PANEL_APPLET_ORIENT_UP:
+		menu_anchor = GDK_GRAVITY_SOUTH_WEST;
+		break;
+	case MATE_PANEL_APPLET_ORIENT_DOWN:
+		widget_anchor = GDK_GRAVITY_SOUTH_WEST;
+		break;
+	case MATE_PANEL_APPLET_ORIENT_LEFT:
+		menu_anchor = GDK_GRAVITY_NORTH_EAST;
+		break;
+	case MATE_PANEL_APPLET_ORIENT_RIGHT:
+		widget_anchor = GDK_GRAVITY_NORTH_EAST;
+		break;
+	}
 	gtk_menu_popup_at_widget (GTK_MENU (menu),
 	                          GTK_WIDGET (applet),
-	                          GDK_GRAVITY_NORTH_WEST,
-	                          GDK_GRAVITY_NORTH_WEST,
+	                          widget_anchor,
+	                          menu_anchor,
 	                          event);
 }
 
@@ -985,13 +998,19 @@ mate_panel_applet_button_release (GtkWidget      *widget,
 	return mate_panel_applet_button_event (applet, event);
 }
 
+/*Open the applet context menu only on Menu key
+ *Do not open it on Return or some applets won't work
+ */
 static gboolean
 mate_panel_applet_key_press_event (GtkWidget   *widget,
 			      GdkEventKey *event)
 {
-	mate_panel_applet_menu_popup (MATE_PANEL_APPLET (widget), (GdkEvent *) event);
-
-	return TRUE;
+    if (event->keyval == GDK_KEY_Menu) {
+        mate_panel_applet_menu_popup (MATE_PANEL_APPLET (widget), (GdkEvent *) event);
+        return TRUE;
+    }
+    else
+        return FALSE;
 }
 
 static void
@@ -1737,10 +1756,12 @@ void _mate_panel_applet_apply_css(GtkWidget* widget, MatePanelAppletBackgroundTy
 	}
 }
 
+#ifdef HAVE_X11
 static void _mate_panel_applet_prepare_css (GtkStyleContext *context)
 {
 	GtkCssProvider  *provider;
 
+	g_return_if_fail (GDK_IS_X11_DISPLAY (gdk_display_get_default ()));
 	provider = gtk_css_provider_new ();
 	gtk_css_provider_load_from_data (provider,
 					 "#PanelPlug {\n"
@@ -1758,10 +1779,12 @@ static void _mate_panel_applet_prepare_css (GtkStyleContext *context)
 					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 	g_object_unref (provider);
 }
+#endif // HAVE_X11
+
 static void
 mate_panel_applet_init (MatePanelApplet *applet)
 {
-	applet->priv = MATE_PANEL_APPLET_GET_PRIVATE (applet);
+	applet->priv = mate_panel_applet_get_instance_private (applet);
 
 	applet->priv->flags  = MATE_PANEL_APPLET_FLAGS_NONE;
 	applet->priv->orient = MATE_PANEL_APPLET_ORIENT_UP;
@@ -1806,34 +1829,34 @@ mate_panel_applet_constructor (GType                  type,
 		return object;
 
 #ifdef HAVE_X11
-	if (!GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+	if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()))
+	{
+		applet->priv->plug = gtk_plug_new (0);
+
+		GdkScreen *screen = gtk_widget_get_screen (GTK_WIDGET (applet->priv->plug));
+		GdkVisual *visual = gdk_screen_get_rgba_visual (screen);
+		gtk_widget_set_visual (GTK_WIDGET (applet->priv->plug), visual);
+		GtkStyleContext *context;
+		context = gtk_widget_get_style_context (GTK_WIDGET(applet->priv->plug));
+		gtk_style_context_add_class (context,"gnome-panel-menu-bar");
+		gtk_style_context_add_class (context,"mate-panel-menu-bar");
+		gtk_widget_set_name (GTK_WIDGET (applet->priv->plug), "PanelPlug");
+		_mate_panel_applet_prepare_css (context);
+
+		g_signal_connect_swapped (G_OBJECT (applet->priv->plug), "embedded",
+					  G_CALLBACK (mate_panel_applet_setup),
+					  applet);
+
+		gtk_container_add (GTK_CONTAINER (applet->priv->plug), GTK_WIDGET (applet));
+	} else
 #endif
 	{ // not using X11
 		g_warning ("Requested construction of an out-of-process applet, which is only possible on X11");
-		return object;
 	}
 
-	applet->priv->plug = gtk_plug_new (0);
-
-	GdkScreen *screen = gtk_widget_get_screen(GTK_WIDGET(applet->priv->plug));
-	GdkVisual *visual = gdk_screen_get_rgba_visual(screen);
-	gtk_widget_set_visual(GTK_WIDGET(applet->priv->plug), visual);
-	GtkStyleContext *context;
-	context = gtk_widget_get_style_context (GTK_WIDGET(applet->priv->plug));
-	gtk_style_context_add_class(context,"gnome-panel-menu-bar");
-	gtk_style_context_add_class(context,"mate-panel-menu-bar");
-	gtk_widget_set_name(GTK_WIDGET(applet->priv->plug), "PanelPlug");
-	_mate_panel_applet_prepare_css(context);
-
-	g_signal_connect_swapped (G_OBJECT (applet->priv->plug), "embedded",
-		                      G_CALLBACK (mate_panel_applet_setup),
-		                      applet);
- 
- 	gtk_container_add (GTK_CONTAINER (applet->priv->plug), GTK_WIDGET (applet));
-
 	return object;
 }
- 
+
 static void
 mate_panel_applet_constructed (GObject* object)
 {
@@ -1874,8 +1897,6 @@ mate_panel_applet_class_init (MatePanelAppletClass *klass)
 
 	gobject_class->finalize = mate_panel_applet_finalize;
 
-	g_type_class_add_private (klass, sizeof (MatePanelAppletPrivate));
-
 	g_object_class_install_property (gobject_class,
 	                  PROP_OUT_OF_PROCESS,
 	                  g_param_spec_boolean ("out-of-process",
@@ -2286,7 +2307,7 @@ _mate_panel_applet_factory_main_internal (const gchar               *factory_id,
 				     GType                      applet_type,
 				     MatePanelAppletFactoryCallback callback,
 					 gpointer                   user_data)
-	
+
 {
 	MatePanelAppletFactory* factory;
 	GClosure* closure;
