@@ -18,8 +18,6 @@
 #include "panel-enums.h"
 #include "panel-enums-gsettings.h"
 
-#define BUTTON_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BUTTON_TYPE_WIDGET, ButtonWidgetPrivate))
-
 struct _ButtonWidgetPrivate {
 	GtkIconTheme     *icon_theme;
 	cairo_surface_t  *surface;
@@ -52,7 +50,7 @@ enum {
 
 #define BUTTON_WIDGET_DISPLACEMENT 2
 
-G_DEFINE_TYPE (ButtonWidget, button_widget, GTK_TYPE_BUTTON)
+G_DEFINE_TYPE_WITH_PRIVATE (ButtonWidget, button_widget, GTK_TYPE_BUTTON)
 
 /* colorshift a surface */
 static void
@@ -177,8 +175,8 @@ button_widget_reload_surface (ButtonWidget *button)
 			panel_load_icon (button->priv->icon_theme,
 					 button->priv->filename,
 					 button->priv->size * scale,
-					 button->priv->orientation & PANEL_VERTICAL_MASK   ? button->priv->size * scale : -1,
-					 button->priv->orientation & PANEL_HORIZONTAL_MASK ? button->priv->size * scale: -1,
+					 (button->priv->orientation & PANEL_VERTICAL_MASK)   ? button->priv->size * scale : -1,
+					 (button->priv->orientation & PANEL_HORIZONTAL_MASK) ? button->priv->size * scale: -1,
 					 &error);
 		if (error) {
 			//FIXME: this is not rendered at button->priv->size
@@ -311,8 +309,8 @@ calc_arrow (PanelOrientation  orientation,
 		if (button_height > 50)
 			button_height = 50;
 	}
-	
-	*size = (orientation & PANEL_HORIZONTAL_MASK ? button_width : button_height) / 2;
+
+	*size = ((orientation & PANEL_HORIZONTAL_MASK) ? button_width : button_height) / 2;
 	*angle = 0;
 
 	switch (orientation) {
@@ -456,7 +454,7 @@ button_widget_get_preferred_width (GtkWidget *widget,
 
 		/* should get this value (50) from gsettings, user defined value in properties of the panel (max_icon_size) OR use 48*/
 		if ( size > 50 )
-			size = 50;	
+			size = 50;
 
 	} else
 		size = gtk_widget_get_allocated_width (parent);
@@ -479,11 +477,11 @@ button_widget_get_preferred_height (GtkWidget *widget,
 		size = gtk_widget_get_allocated_height (parent);
 	else {
 		size = gtk_widget_get_allocated_width (parent);
-		
+
 		/* should get this value (50) from gsettings, user defined value in properties of the panel (max_icon_size) OR use 48*/
 		if ( size > 50 )
-			size = 50;	
-	
+			size = 50;
+
 	}
 
 	*minimal_height = *natural_height = size;
@@ -499,14 +497,14 @@ button_widget_size_allocate (GtkWidget     *widget,
 	/* should get this value (50) from gsettings, user defined value in properties of the panel (max_icon_size) OR use 48?*/
 	if (button_widget->priv->orientation & PANEL_HORIZONTAL_MASK) {
 		if ( allocation->height > 50 ) {
-			allocation->width = 50;	
+			allocation->width = 50;
 		}
 	} else {
 		if ( allocation->width > 50 ) {
-			allocation->height = 50;	
+			allocation->height = 50;
 		}
 	}
-	
+
 	GTK_WIDGET_CLASS (button_widget_parent_class)->size_allocate (widget, allocation);
 
 	if (button_widget->priv->orientation & PANEL_HORIZONTAL_MASK)
@@ -602,18 +600,18 @@ button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 static void
 button_widget_init (ButtonWidget *button)
 {
-	button->priv = BUTTON_WIDGET_GET_PRIVATE (button);
+	button->priv = button_widget_get_instance_private (button);
 
 	button->priv->icon_theme = NULL;
 	button->priv->surface    = NULL;
 	button->priv->surface_hc = NULL;
 
 	button->priv->filename   = NULL;
-	
+
 	button->priv->orientation = PANEL_ORIENTATION_TOP;
 
 	button->priv->size = 0;
-	
+
 	button->priv->activatable   = FALSE;
 	button->priv->ignore_leave  = FALSE;
 	button->priv->arrow         = FALSE;
@@ -631,8 +629,6 @@ button_widget_class_init (ButtonWidgetClass *klass)
 	gobject_class->get_property = button_widget_get_property;
 	gobject_class->set_property = button_widget_set_property;
 
-	g_type_class_add_private (klass, sizeof (ButtonWidgetPrivate));
-	  
 	widget_class->realize            = button_widget_realize;
 	widget_class->unrealize          = button_widget_unrealize;
 	widget_class->size_allocate      = button_widget_size_allocate;
@@ -714,7 +710,7 @@ button_widget_new (const char       *filename,
 			"orientation", orientation,
 			"icon-name", filename,
 			NULL);
-	
+
 	return retval;
 }
 
