@@ -20,7 +20,6 @@
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <gdk/gdkx.h>
 
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-glib.h>
@@ -34,11 +33,12 @@
 #include "panel-util.h"
 #include "panel-config-global.h"
 #include "panel-profile.h"
+#ifdef HAVE_X11
 #include "xstuff.h"
+#endif
 #include "panel-toplevel.h"
 #include "panel-a11y.h"
 #include "panel-globals.h"
-#include "panel-multiscreen.h"
 #include "panel-lockdown.h"
 #include "panel-ditem-editor.h"
 #include "panel-icon-names.h"
@@ -88,7 +88,7 @@ launcher_widget_destroy_open_dialogs (Launcher *launcher)
 }
 
 static void
-launcher_register_error_dialog (Launcher *launcher, 
+launcher_register_error_dialog (Launcher *launcher,
 				GtkWidget *dialog)
 {
 	launcher->error_dialogs = g_slist_append (launcher->error_dialogs,
@@ -183,7 +183,9 @@ drag_data_received_cb (GtkWidget        *widget,
 	int      i;
 	GList   *file_list;
 
-	if (panel_global_config_get_enable_animations ()) {
+	// The animation uses X specific functionality
+#ifdef HAVE_X11
+	if (is_using_x11 () && panel_global_config_get_enable_animations ()) {
 		cairo_surface_t *surface;
 		surface = button_widget_get_surface (BUTTON_WIDGET (widget));
 		xstuff_zoom_animate (widget,
@@ -192,6 +194,7 @@ drag_data_received_cb (GtkWidget        *widget,
 				     NULL);
 		cairo_surface_destroy (surface);
 	}
+#endif
 
 	file_list = NULL;
 	uris = g_uri_list_extract_uris ((const char *) gtk_selection_data_get_data (selection_data));
@@ -311,7 +314,7 @@ is_this_drop_ok (GtkWidget      *widget,
 	return l ? TRUE : FALSE;
 }
 
-static void  
+static void
 drag_leave_cb(GtkWidget	       *widget,
 	      GdkDragContext   *context,
 	      guint             time,
@@ -401,7 +404,9 @@ static void
 clicked_cb (Launcher  *launcher,
 		  GtkWidget        *widget)
 {
-	if (panel_global_config_get_enable_animations ()) {
+
+#ifdef HAVE_X11
+	if (is_using_x11 () && panel_global_config_get_enable_animations ()) {
 		cairo_surface_t *surface;
 		surface = button_widget_get_surface (BUTTON_WIDGET (widget));
 		xstuff_zoom_animate (widget,
@@ -410,6 +415,7 @@ clicked_cb (Launcher  *launcher,
 				     NULL);
 		cairo_surface_destroy (surface);
 	}
+#endif
 
 	launcher_launch (launcher, NULL);
 
@@ -810,7 +816,7 @@ launcher_properties (Launcher  *launcher)
 							launcher->location,
 							_("Launcher Properties"));
 
-	panel_widget_register_open_dialog (PANEL_WIDGET 
+	panel_widget_register_open_dialog (PANEL_WIDGET
 					   (gtk_widget_get_parent (launcher->info->widget)),
 					   launcher->prop_dialog);
 
@@ -896,7 +902,7 @@ launcher_load_from_gsettings (PanelWidget *panel_widget,
 
 	path = g_strdup_printf ("%s%s/", PANEL_OBJECT_PATH, id);
 	settings = g_settings_new_with_path (PANEL_OBJECT_SCHEMA, path);
-	g_free (path); 
+	g_free (path);
 
 	launcher_location = g_settings_get_string (settings, PANEL_OBJECT_LAUNCHER_LOCATION_KEY);
 
@@ -1113,7 +1119,7 @@ panel_launcher_create_copy (PanelToplevel *toplevel,
 
 	copied = g_file_copy (source, dest, G_FILE_COPY_OVERWRITE,
 			      NULL, NULL, NULL, NULL);
-	
+
 	if (!copied) {
 		g_free (new_location);
 		return FALSE;
