@@ -20,9 +20,15 @@
  *
  */
 
+#include <config.h>
 #include <string.h>
+
 #include <gtk/gtk.h>
+
+#ifdef HAVE_X11
 #include <gtk/gtkx.h>
+#endif
+
 #include <panel-applets-manager.h>
 #include "panel-applet-container.h"
 #include "panel-marshal.h"
@@ -69,17 +75,16 @@ static const AppletPropertyInfo applet_properties [] = {
 	{ "locked-down", "LockedDown" }
 };
 
-#define MATE_PANEL_APPLET_CONTAINER_GET_PRIVATE(o) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_APPLET_CONTAINER, MatePanelAppletContainerPrivate))
-
 #define MATE_PANEL_APPLET_BUS_NAME            "org.mate.panel.applet.%s"
 #define MATE_PANEL_APPLET_FACTORY_INTERFACE   "org.mate.panel.applet.AppletFactory"
 #define MATE_PANEL_APPLET_FACTORY_OBJECT_PATH "/org/mate/panel/applet/%s"
 #define MATE_PANEL_APPLET_INTERFACE           "org.mate.panel.applet.Applet"
 
+#ifdef HAVE_X11
 static gboolean mate_panel_applet_container_plug_removed (MatePanelAppletContainer *container);
+#endif
 
-G_DEFINE_TYPE (MatePanelAppletContainer, mate_panel_applet_container, GTK_TYPE_EVENT_BOX);
+G_DEFINE_TYPE_WITH_PRIVATE (MatePanelAppletContainer, mate_panel_applet_container, GTK_TYPE_EVENT_BOX);
 
 GQuark mate_panel_applet_container_error_quark (void)
 {
@@ -88,7 +93,7 @@ GQuark mate_panel_applet_container_error_quark (void)
 
 static void mate_panel_applet_container_init(MatePanelAppletContainer* container)
 {
-	container->priv = MATE_PANEL_APPLET_CONTAINER_GET_PRIVATE (container);
+	container->priv = mate_panel_applet_container_get_instance_private (container);
 
 	container->priv->pending_ops = g_hash_table_new_full (g_direct_hash,
 							      g_direct_equal,
@@ -100,15 +105,23 @@ static void
 panel_applet_container_setup (MatePanelAppletContainer *container)
 {
 	if (container->priv->out_of_process) {
-		container->priv->socket = gtk_socket_new ();
+#ifdef HAVE_X11
+		if (GDK_IS_X11_DISPLAY (gdk_display_get_default ())) {
+			container->priv->socket = gtk_socket_new ();
 
-		g_signal_connect_swapped (container->priv->socket,
-		                          "plug-removed",
-		                          G_CALLBACK (mate_panel_applet_container_plug_removed),
-		                          container);
+			g_signal_connect_swapped (container->priv->socket,
+						"plug-removed",
+						G_CALLBACK (mate_panel_applet_container_plug_removed),
+						container);
 
-		gtk_container_add (GTK_CONTAINER (container), container->priv->socket);
-		gtk_widget_show (container->priv->socket);
+			gtk_container_add (GTK_CONTAINER (container), container->priv->socket);
+			gtk_widget_show (container->priv->socket);
+		} else
+#endif
+		{ // Not using X11
+			g_warning("%s requested out-of-process container, which is only supported on X11",
+				  container->priv->iid);
+		}
 	} else {
 		GtkWidget *applet;
 
@@ -175,8 +188,6 @@ mate_panel_applet_container_class_init (MatePanelAppletContainerClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (MatePanelAppletContainerPrivate));
-
 	gobject_class->dispose = mate_panel_applet_container_dispose;
 
 	signals[APPLET_BROKEN] =
@@ -258,9 +269,12 @@ mate_panel_applet_container_new (void)
 	return container;
 }
 
+#ifdef HAVE_X11
 static gboolean
 mate_panel_applet_container_plug_removed (MatePanelAppletContainer *container)
 {
+	g_return_val_if_fail (GDK_IS_X11_DISPLAY (gtk_widget_get_display (GTK_WIDGET (container))), FALSE);
+
 	if (!container->priv->applet_proxy)
 		return FALSE;
 
@@ -281,6 +295,7 @@ mate_panel_applet_container_plug_removed (MatePanelAppletContainer *container)
 	 */
 	return FALSE;
 }
+#endif // HAVE_X11
 
 static void
 mate_panel_applet_container_child_signal (GDBusProxy           *proxy,
@@ -373,10 +388,13 @@ on_proxy_appeared (GObject      *source_object,
 
 	panel_applet_container_setup (container);
 
+#ifdef HAVE_X11
+	// xid always <= 0 when not using X11
 	if (container->priv->xid > 0) {
 		gtk_socket_add_id (GTK_SOCKET (container->priv->socket),
 				   container->priv->xid);
 	}
+#endif
 
 	/* g_async_result_get_source_object returns new ref */
 	g_object_unref (container);
@@ -510,7 +528,14 @@ mate_panel_applet_container_get_applet (MatePanelAppletContainer *container,
 
 	/* we can't use the screen of the container widget since it's not in a
 	 * widget hierarchy yet */
-	screen_number = gdk_x11_screen_get_screen_number (screen);
+#ifdef HAVE_X11
+	if (GDK_IS_X11_DISPLAY (gdk_screen_get_display (screen))) {
+		screen_number = gdk_x11_screen_get_screen_number (screen);
+	} else
+#endif
+	{ // Not using X11
+		screen_number = 0;
+	}
 
 	data = g_new (AppletFactoryData, 1);
 	data->result = result;
@@ -594,7 +619,7 @@ set_applet_property_cb (GObject      *source_object,
 	g_object_unref (container);
 }
 
-void
+gconstpointer
 mate_panel_applet_container_child_set (MatePanelAppletContainer *container,
 				  const gchar          *property_name,
 				  const GVariant       *value,
@@ -607,7 +632,7 @@ mate_panel_applet_container_child_set (MatePanelAppletContainer *container,
 	GSimpleAsyncResult       *result;
 
 	if (!proxy)
-		return;
+		return NULL;
 
 	info = mate_panel_applet_container_child_property_get_info (property_name);
 	if (!info) {
@@ -617,7 +642,7 @@ mate_panel_applet_container_child_set (MatePanelAppletContainer *container,
 						     MATE_PANEL_APPLET_CONTAINER_INVALID_CHILD_PROPERTY,
 						     "%s: Applet has no child property named `%s'",
 						     G_STRLOC, property_name);
-		return;
+		return NULL;
 	}
 
 	result = g_simple_async_result_new (G_OBJECT (container),
@@ -645,6 +670,8 @@ mate_panel_applet_container_child_set (MatePanelAppletContainer *container,
 				-1, cancellable,
 				set_applet_property_cb,
 				result);
+
+	return result;
 }
 
 gboolean
@@ -696,7 +723,7 @@ get_applet_property_cb (GObject      *source_object,
 	g_object_unref (container);
 }
 
-void
+gconstpointer
 mate_panel_applet_container_child_get (MatePanelAppletContainer *container,
 				  const gchar          *property_name,
 				  GCancellable         *cancellable,
@@ -708,7 +735,7 @@ mate_panel_applet_container_child_get (MatePanelAppletContainer *container,
 	GSimpleAsyncResult       *result;
 
 	if (!proxy)
-		return;
+		return NULL;
 
 	info = mate_panel_applet_container_child_property_get_info (property_name);
 	if (!info) {
@@ -718,7 +745,7 @@ mate_panel_applet_container_child_get (MatePanelAppletContainer *container,
 						     MATE_PANEL_APPLET_CONTAINER_INVALID_CHILD_PROPERTY,
 						     "%s: Applet has no child property named `%s'",
 						     G_STRLOC, property_name);
-		return;
+		return NULL;
 	}
 
 	result = g_simple_async_result_new (G_OBJECT (container),
@@ -744,6 +771,8 @@ mate_panel_applet_container_child_get (MatePanelAppletContainer *container,
 				-1, cancellable,
 				get_applet_property_cb,
 				result);
+
+	return result;
 }
 
 GVariant *
@@ -826,3 +855,14 @@ mate_panel_applet_container_child_popup_menu_finish (MatePanelAppletContainer *c
 
 	return !g_simple_async_result_propagate_error (simple, error);
 }
+
+void
+mate_panel_applet_container_cancel_operation (MatePanelAppletContainer *container,
+                                              gconstpointer             operation)
+{
+	gpointer value = g_hash_table_lookup (container->priv->pending_ops, operation);
+	if (value == NULL)
+		return;
+
+	g_cancellable_cancel (G_CANCELLABLE (value));
+}
