@@ -178,7 +178,7 @@ gboolean panel_show_uri(GdkScreen* screen, const gchar* uri, guint32 timestamp,
 		return panel_show_caja_search_uri(screen, uri, timestamp, error);
 	}
 
-	gtk_show_uri(screen, uri, timestamp, &local_error);
+	gtk_show_uri_on_window (NULL, uri,timestamp, &local_error);
 
 	return _panel_show_handle_error(uri, screen, local_error, error);
 }
@@ -283,8 +283,7 @@ panel_show_help (GdkScreen    *screen,
 	else
 		uri = g_strdup_printf ("help:%s", doc);
 
-	gtk_show_uri (screen, uri, gtk_get_current_event_time (), &local_error);
-
+	gtk_show_uri_on_window (NULL, uri, gtk_get_current_event_time (), &local_error);
 	g_free (uri);
 
 	return _panel_show_help_handle_error (doc, screen, local_error, error);
