@@ -46,7 +46,6 @@
 #include "panel-config-global.h"
 #include "panel-profile.h"
 #include "panel-typebuiltins.h"
-#include "panel-force-quit.h"
 #include "panel-util.h"
 #include "panel-session.h"
 #include "panel-globals.h"
@@ -56,9 +55,10 @@
 #include "panel-icon-names.h"
 #include "panel-schemas.h"
 
-G_DEFINE_TYPE (PanelActionButton, panel_action_button, BUTTON_TYPE_WIDGET)
-
-#define PANEL_ACTION_BUTTON_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_ACTION_BUTTON, PanelActionButtonPrivate))
+#ifdef HAVE_X11
+#include <gdk/gdkx.h>
+#include "panel-force-quit.h"
+#endif
 
 enum {
 	PROP_0,
@@ -74,6 +74,8 @@ struct _PanelActionButtonPrivate {
 	guint                  dnd_enabled : 1;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (PanelActionButton, panel_action_button, BUTTON_TYPE_WIDGET)
+
 static void
 panel_action_button_type_changed (GSettings       *settings,
 								  gchar           *key,
@@ -106,7 +108,7 @@ obsolete_enum_to_string (ObsoleteEnumStringPair lookup_table[],
                          gint enum_value)
 {
   int i = 0;
-  
+
   while (lookup_table[i].str != NULL)
     {
       if (lookup_table[i].enum_value == enum_value)
@@ -124,7 +126,7 @@ obsolete_string_to_enum (ObsoleteEnumStringPair lookup_table[],
                       gint* enum_value_retloc)
 {
   int i = 0;
-  
+
   while (lookup_table[i].str != NULL)
     {
       if (g_ascii_strcasecmp (lookup_table[i].str, str) == 0)
@@ -188,7 +190,7 @@ panel_action_lock_setup_menu (PanelActionButton *button)
 
 	mate_panel_applet_add_callback (button->priv->info,
 				   "prefs",
-				   GTK_STOCK_PROPERTIES,
+				   "document-properties",
 				   _("_Properties"),
 				   screensaver_properties_enabled);
 }
@@ -281,8 +283,24 @@ panel_action_search (GtkWidget *widget)
 static void
 panel_action_force_quit (GtkWidget *widget)
 {
-	panel_force_quit (gtk_widget_get_screen (widget),
-			  gtk_get_current_event_time ());
+	GtkWidget *dialog;
+	GtkDialogFlags flags;
+
+#ifdef HAVE_X11
+	if (GDK_IS_X11_DISPLAY (gtk_widget_get_display (widget))) {
+		panel_force_quit (gtk_widget_get_screen (widget),
+				  gtk_get_current_event_time ());
+		return;
+	}
+#endif
+	flags = GTK_DIALOG_DESTROY_WITH_PARENT;
+	dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
+					 flags,
+					 GTK_MESSAGE_ERROR,
+					 GTK_BUTTONS_CLOSE,
+					 "Force quit only available in X11");
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 /* Connect Server
@@ -610,8 +628,6 @@ panel_action_button_class_init (PanelActionButtonClass *klass)
 
 	button_class->clicked       = panel_action_button_clicked;
 
-	g_type_class_add_private (klass, sizeof (PanelActionButtonPrivate));
-
 	g_object_class_install_property (
 			gobject_class,
 			PROP_ACTION_TYPE,
@@ -635,7 +651,7 @@ panel_action_button_class_init (PanelActionButtonClass *klass)
 static void
 panel_action_button_init (PanelActionButton *button)
 {
-	button->priv = PANEL_ACTION_BUTTON_GET_PRIVATE (button);
+	button->priv = panel_action_button_get_instance_private (button);
 
 	button->priv->type = PANEL_ACTION_NONE;
 	button->priv->info = NULL;
@@ -733,7 +749,7 @@ panel_action_button_load (PanelActionButtonType  type,
 
 	mate_panel_applet_add_callback (button->priv->info,
 				   "help",
-				   GTK_STOCK_HELP,
+				   "help-browser",
 				   _("_Help"),
 				   NULL);
 
