@@ -27,7 +27,6 @@
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <gdk/gdkx.h>
 
 #include <matemenu-tree.h>
 
@@ -54,6 +53,13 @@
 #include "panel-schemas.h"
 #include "panel-stock-icons.h"
 
+#ifdef HAVE_X11
+#include "xstuff.h"
+#endif
+#ifdef HAVE_WAYLAND
+#include "gdk/gdkwayland.h"
+#endif
+
 typedef struct {
 	PanelWidget *panel_widget;
 
@@ -104,6 +110,7 @@ typedef struct {
 	char                  *menu_filename;
 	char                  *menu_path;
 	char                  *iid;
+	gboolean               enabled;
 	gboolean               static_data;
 } PanelAddtoItemInfo;
 
@@ -123,6 +130,7 @@ static PanelAddtoItemInfo special_addto_items [] = {
 	  NULL,
 	  NULL,
 	  "LAUNCHER:ASK",
+	  TRUE,
 	  TRUE },
 
 	{ PANEL_ADDTO_LAUNCHER_MENU,
@@ -134,6 +142,7 @@ static PanelAddtoItemInfo special_addto_items [] = {
 	  NULL,
 	  NULL,
 	  "LAUNCHER:MENU",
+	  TRUE,
 	  TRUE }
 
 };
@@ -141,25 +150,27 @@ static PanelAddtoItemInfo special_addto_items [] = {
 static PanelAddtoItemInfo internal_addto_items [] = {
 
 	{ PANEL_ADDTO_MENU,
-	  N_("Main Menu"),
-	  N_("The main MATE menu"),
+	  N_("Compact Menu"),
+	  N_("A compact menu"),
 	  PANEL_ICON_MAIN_MENU,
 	  PANEL_ACTION_NONE,
 	  NULL,
 	  NULL,
 	  NULL,
 	  "MENU:MAIN",
+	  TRUE,
 	  TRUE },
 
 	{ PANEL_ADDTO_MENUBAR,
-	  N_("Menu Bar"),
-	  N_("A custom menu bar"),
+	  N_("Classic Menu"),
+	  N_("The classic Applications, Places and System menu bar"),
 	  PANEL_ICON_MAIN_MENU,
 	  PANEL_ACTION_NONE,
 	  NULL,
 	  NULL,
 	  NULL,
 	  "MENUBAR:NEW",
+	  TRUE,
 	  TRUE },
 
 	{ PANEL_ADDTO_SEPARATOR,
@@ -171,6 +182,7 @@ static PanelAddtoItemInfo internal_addto_items [] = {
 	  NULL,
 	  NULL,
 	  "SEPARATOR:NEW",
+	  TRUE,
 	  TRUE },
 
 	{ PANEL_ADDTO_DRAWER,
@@ -182,6 +194,7 @@ static PanelAddtoItemInfo internal_addto_items [] = {
 	  NULL,
 	  NULL,
 	  "DRAWER:NEW",
+	  TRUE,
 	  TRUE }
 };
 
@@ -190,6 +203,7 @@ enum {
 	COLUMN_TEXT,
 	COLUMN_DATA,
 	COLUMN_SEARCH,
+	COLUMN_ENABLED,
 	NUMBER_COLUMNS
 };
 
@@ -241,6 +255,7 @@ panel_addto_prepend_internal_applets (GSList *list)
 		info->description = g_strdup (panel_action_get_tooltip (i));
 		info->icon        = g_strdup (panel_action_get_icon_name (i));
 		info->iid         = g_strdup (panel_action_get_drag_id (i));
+		info->enabled     = TRUE;
 		info->static_data = FALSE;
 
 		list = g_slist_prepend (list, info);
@@ -382,6 +397,7 @@ panel_addto_query_applets (GSList *list)
 	for (l = applet_list; l; l = g_list_next (l)) {
 		MatePanelAppletInfo *info;
 		const char *iid, *name, *description, *icon;
+		gboolean enabled;
 		PanelAddtoItemInfo *applet;
 
 		info = (MatePanelAppletInfo *)l->data;
@@ -395,12 +411,29 @@ panel_addto_query_applets (GSList *list)
 			continue;
 		}
 
+		enabled = TRUE;
+#ifdef HAVE_X11
+		if (GDK_IS_X11_DISPLAY (gdk_display_get_default ()) &&
+		    !mate_panel_applet_info_get_x11_supported (info)) {
+			enabled = FALSE;
+			description = _("Not compatible with X11");
+		}
+#endif
+#ifdef HAVE_WAYLAND
+		if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()) &&
+		    !mate_panel_applet_info_get_wayland_supported (info)) {
+			enabled = FALSE;
+			description = _("Not compatible with Wayland");
+		}
+#endif
+
 		applet = g_new0 (PanelAddtoItemInfo, 1);
 		applet->type = PANEL_ADDTO_APPLET;
 		applet->name = g_strdup (name);
 		applet->description = g_strdup (description);
 		applet->icon = g_strdup (icon);
 		applet->iid = g_strdup (iid);
+		applet->enabled = enabled;
 		applet->static_data = FALSE;
 
 		list = g_slist_prepend (list, applet);
@@ -426,6 +459,7 @@ panel_addto_append_item (PanelAddtoDialog *dialog,
 				    COLUMN_TEXT, NULL,
 				    COLUMN_DATA, NULL,
 				    COLUMN_SEARCH, NULL,
+				    COLUMN_ENABLED, TRUE,
 				    -1);
 	} else {
 		gtk_list_store_append (model, &iter);
@@ -438,6 +472,7 @@ panel_addto_append_item (PanelAddtoDialog *dialog,
 				    COLUMN_TEXT, text,
 				    COLUMN_DATA, applet,
 				    COLUMN_SEARCH, applet->name,
+				    COLUMN_ENABLED, applet->enabled,
 				    -1);
 
 		g_free (text);
@@ -488,7 +523,8 @@ panel_addto_make_applet_model (PanelAddtoDialog *dialog)
 				    G_TYPE_STRING,
 				    G_TYPE_STRING,
 				    G_TYPE_POINTER,
-				    G_TYPE_STRING);
+				    G_TYPE_STRING,
+				    G_TYPE_BOOLEAN);
 
 	if (panel_profile_id_lists_are_writable ()) {
 		panel_addto_append_special_applets (dialog, model);
@@ -654,6 +690,7 @@ panel_addto_populate_application_model (GtkTreeStore *store,
 				    COLUMN_TEXT, text,
 				    COLUMN_DATA, &(data->item_info),
 				    COLUMN_SEARCH, data->item_info.name,
+				    COLUMN_ENABLED, data->item_info.enabled,
 				    -1);
 
 		g_free (text);
@@ -675,7 +712,12 @@ static void panel_addto_make_application_model(PanelAddtoDialog* dialog)
 	if (dialog->filter_application_model != NULL)
 		return;
 
-	store = gtk_tree_store_new(NUMBER_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING);
+	store = gtk_tree_store_new (NUMBER_COLUMNS,
+				    G_TYPE_STRING,
+				    G_TYPE_STRING,
+				    G_TYPE_POINTER,
+				    G_TYPE_STRING,
+				    G_TYPE_BOOLEAN);
 
 	tree = matemenu_tree_new ("mate-applications.menu", MATEMENU_TREE_FLAGS_SORT_DISPLAY_NAME);
 	if (! matemenu_tree_load_sync (tree, &error)) {
@@ -706,7 +748,13 @@ static void panel_addto_make_application_model(PanelAddtoDialog* dialog)
 		GtkTreeIter iter;
 
 		gtk_tree_store_append(store, &iter, NULL);
-		gtk_tree_store_set(store, &iter, COLUMN_ICON_NAME, NULL, COLUMN_TEXT, NULL, COLUMN_DATA, NULL, COLUMN_SEARCH, NULL, -1);
+		gtk_tree_store_set (store, &iter,
+				    COLUMN_ICON_NAME, NULL,
+				    COLUMN_TEXT, NULL,
+				    COLUMN_DATA, NULL,
+				    COLUMN_SEARCH, NULL,
+				    COLUMN_ENABLED, TRUE,
+				    -1);
 
 		panel_addto_make_application_list(&dialog->settings_list, root, "mate-settings.menu");
 		panel_addto_populate_application_model(store, NULL, dialog->settings_list);
@@ -1107,6 +1155,25 @@ panel_addto_search_entry_activated (GtkWidget        *entry,
 			     PANEL_ADDTO_RESPONSE_ADD);
 }
 
+static gboolean
+panel_addto_selection_func (GtkTreeSelection  *selection,
+			    GtkTreeModel      *model,
+			    GtkTreePath       *path,
+			    gboolean           path_currently_selected,
+			    gpointer           data)
+{
+	GtkTreeIter         iter;
+	gboolean            enabled;
+
+	if (!gtk_tree_model_get_iter (model, &iter, path))
+		return FALSE;
+
+	gtk_tree_model_get (model, &iter,
+			    COLUMN_ENABLED, &enabled,
+			    -1);
+	return enabled;
+}
+
 static void
 panel_addto_selection_changed (GtkTreeSelection *selection,
 			       PanelAddtoDialog *dialog)
@@ -1317,6 +1384,7 @@ panel_addto_dialog_new (PanelWidget *panel_widget)
 						     -1, NULL,
 						     renderer,
 						     "icon_name", COLUMN_ICON_NAME,
+						     "sensitive", COLUMN_ENABLED,
 						     NULL);
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
@@ -1324,6 +1392,7 @@ panel_addto_dialog_new (PanelWidget *panel_widget)
 						     -1, NULL,
 						     renderer,
 						     "markup", COLUMN_TEXT,
+						     "sensitive", COLUMN_ENABLED,
 						     NULL);
 
 	//FIXME use the same search than the one for the search entry?
@@ -1343,6 +1412,8 @@ panel_addto_dialog_new (PanelWidget *panel_widget)
 					   COLUMN_TEXT);
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
 
+	gtk_tree_selection_set_select_function (selection, panel_addto_selection_func, NULL, NULL);
+
 	g_signal_connect (selection, "changed",
 			  G_CALLBACK (panel_addto_selection_changed),
 			  dialog);
@@ -1375,7 +1446,8 @@ panel_addto_present (GtkMenuItem *item,
 	PanelToplevel *toplevel;
 	PanelData     *pd;
 	GdkScreen *screen;
-	gint screen_height;
+	GdkMonitor *monitor;
+	GdkRectangle monitor_geom;
 	gint height;
 
 	toplevel = panel_widget->toplevel;
@@ -1389,8 +1461,10 @@ panel_addto_present (GtkMenuItem *item,
 				     panel_addto_dialog_quark);
 
 	screen = gtk_window_get_screen (GTK_WINDOW (toplevel));
-	screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
-	height = MIN (MAX_ADDTOPANEL_HEIGHT, 3 * (screen_height / 4));
+	monitor = gdk_display_get_monitor_at_window (gtk_widget_get_display (GTK_WIDGET (toplevel)),
+						     gtk_widget_get_window (GTK_WIDGET (toplevel)));
+	gdk_monitor_get_geometry (monitor, &monitor_geom);
+	height = MIN (MAX_ADDTOPANEL_HEIGHT, 3 * (monitor_geom.height / 4));
 
 	if (!dialog) {
 		dialog = panel_addto_dialog_new (panel_widget);
