@@ -31,7 +31,6 @@
 
 #include <gio/gio.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
 
 #include <libpanel-util/panel-gtk.h>
 
@@ -43,7 +42,9 @@
 #include "panel-background.h"
 #include "panel-lockdown.h"
 #include "panel-stock-icons.h"
+#ifdef HAVE_X11
 #include "xstuff.h"
+#endif
 #include "panel-schemas.h"
 
 #include "panel-applet-frame.h"
@@ -75,10 +76,6 @@ struct _MatePanelAppletFrameActivating {
 
 /* MatePanelAppletFrame implementation */
 
-G_DEFINE_TYPE (MatePanelAppletFrame, mate_panel_applet_frame, GTK_TYPE_EVENT_BOX)
-
-#define MATE_PANEL_APPLET_FRAME_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_APPLET_FRAME, MatePanelAppletFramePrivate))
-
 #define HANDLE_SIZE 10
 #define MATE_PANEL_APPLET_PREFS_PATH "/org/mate/panel/objects/%s/prefs/"
 
@@ -96,6 +93,8 @@ struct _MatePanelAppletFramePrivate {
 	guint            has_handle : 1;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (MatePanelAppletFrame, mate_panel_applet_frame, GTK_TYPE_EVENT_BOX)
+
 static gboolean
 mate_panel_applet_frame_draw (GtkWidget *widget,
                          cairo_t   *cr)
@@ -458,14 +457,12 @@ mate_panel_applet_frame_class_init (MatePanelAppletFrameClass *klass)
 	widget_class->size_allocate        = mate_panel_applet_frame_size_allocate;
 	widget_class->button_press_event   = mate_panel_applet_frame_button_changed;
 	widget_class->button_release_event = mate_panel_applet_frame_button_changed;
-
-	g_type_class_add_private (klass, sizeof (MatePanelAppletFramePrivate));
 }
 
 static void
 mate_panel_applet_frame_init (MatePanelAppletFrame *frame)
 {
-	frame->priv = MATE_PANEL_APPLET_FRAME_GET_PRIVATE (frame);
+	frame->priv = mate_panel_applet_frame_get_instance_private (frame);
 
 	frame->priv->panel       = NULL;
 	frame->priv->orientation = PANEL_ORIENTATION_TOP;
@@ -746,8 +743,10 @@ _mate_panel_applet_frame_applet_broken (MatePanelAppletFrame *frame)
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (frame));
 
-	if (xstuff_is_display_dead ())
+#ifdef HAVE_X11
+	if (is_using_x11 () && xstuff_is_display_dead ())
 		return;
+#endif
 
 	if (frame->priv->iid) {
 		MatePanelAppletInfo *info;
@@ -800,8 +799,15 @@ _mate_panel_applet_frame_applet_broken (MatePanelAppletFrame *frame)
 
 	gtk_widget_show (dialog);
 
-	gtk_window_present_with_time (GTK_WINDOW (dialog),
-				      gdk_x11_get_server_time (gtk_widget_get_window (GTK_WIDGET (dialog))));
+#ifdef HAVE_X11
+	if (GDK_IS_X11_DISPLAY (gtk_widget_get_display (dialog)))
+		gtk_window_present_with_time (GTK_WINDOW (dialog),
+					      gdk_x11_get_server_time (gtk_widget_get_window (GTK_WIDGET (dialog))));
+	else
+#endif
+	{ // Not using X11
+		gtk_window_present(GTK_WINDOW (dialog));
+	}
 
 	g_free (dialog_txt);
 }
