@@ -27,9 +27,15 @@
 #ifndef __PANEL_BACKGROUND_MONITOR_H__
 #define __PANEL_BACKGROUND_MONITOR_H__
 
+#ifdef PACKAGE_NAME // only check HAVE_X11 if config.h has been included
+#ifndef HAVE_X11
+#error file should only be included when HAVE_X11 is enabled
+#endif
+#endif
+
 #include <glib.h>
 #include <glib-object.h>
-#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 
 #define PANEL_TYPE_BACKGROUND_MONITOR         (panel_background_monitor_get_type ())
 #define PANEL_BACKGROUND_MONITOR(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o),      \
@@ -49,9 +55,8 @@
 typedef struct _PanelBackgroundMonitorClass PanelBackgroundMonitorClass;
 typedef struct _PanelBackgroundMonitor      PanelBackgroundMonitor;
 
-#if GTK_CHECK_VERSION(3, 0, 0)
 gboolean                gdk_window_check_composited_wm          (GdkWindow* window);
-#endif
+
 GType                   panel_background_monitor_get_type       (void);
 PanelBackgroundMonitor *panel_background_monitor_get_for_screen (GdkScreen *screen);
 GdkPixbuf              *panel_background_monitor_get_region     (PanelBackgroundMonitor *monitor,
