@@ -28,9 +28,6 @@
 
 #include "panel-menu-bar.h"
 
-#include <X11/Xlib.h>
-#include <gdk/gdkx.h>
-
 #include <string.h>
 #include <glib/gi18n.h>
 
@@ -52,10 +49,6 @@
 #include "panel-icon-names.h"
 #include "panel-schemas.h"
 
-G_DEFINE_TYPE (PanelMenuBar, panel_menu_bar, GTK_TYPE_MENU_BAR)
-
-#define PANEL_MENU_BAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_MENU_BAR, PanelMenuBarPrivate))
-
 struct _PanelMenuBarPrivate {
 	AppletInfo* info;
 	PanelWidget* panel;
@@ -68,8 +61,6 @@ struct _PanelMenuBarPrivate {
 	GSettings* settings;
 
 	PanelOrientation orientation;
-
-	Window interrupted_window;
 };
 
 enum {
@@ -77,6 +68,8 @@ enum {
 	PROP_ORIENTATION,
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (PanelMenuBar, panel_menu_bar, GTK_TYPE_MENU_BAR)
+
 static void panel_menu_bar_update_text_gravity(PanelMenuBar* menubar);
 
 static gboolean panel_menu_bar_reinit_tooltip(GtkWidget* widget, PanelMenuBar* menubar)
@@ -88,15 +81,6 @@ static gboolean panel_menu_bar_reinit_tooltip(GtkWidget* widget, PanelMenuBar* m
 	return FALSE;
 }
 
-static gboolean panel_menu_bar_deactivate (GtkWidget* widget, PanelMenuBar* menubar)
-{
-	GtkWidget *toplevel = gtk_widget_get_toplevel (widget);
-	panel_util_set_current_active_window (toplevel, menubar->priv->interrupted_window);
-	menubar->priv->interrupted_window = None;
-
-	return FALSE;
-}
-
 static gboolean panel_menu_bar_hide_tooltip_and_focus(GtkWidget* widget, PanelMenuBar* menubar)
 {
 	/* remove focus that would be drawn on the currently focused child of
@@ -122,7 +106,6 @@ static void panel_menu_bar_setup_tooltip(PanelMenuBar* menubar)
 
 	/* Reset tooltip when the menu bar is not used */
 	g_signal_connect(GTK_MENU_SHELL (menubar), "deactivate", G_CALLBACK (panel_menu_bar_reinit_tooltip), menubar);
-	g_signal_connect(GTK_MENU_SHELL (menubar), "deactivate", G_CALLBACK (panel_menu_bar_deactivate), menubar);
 }
 
 static void panel_menu_bar_update_visibility (GSettings* settings, gchar* key, PanelMenuBar* menubar)
@@ -160,7 +143,7 @@ static void panel_menu_bar_init(PanelMenuBar* menubar)
 {
 	GtkCssProvider *provider;
 
-	menubar->priv = PANEL_MENU_BAR_GET_PRIVATE(menubar);
+	menubar->priv = panel_menu_bar_get_instance_private(menubar);
 
 	provider = gtk_css_provider_new ();
 	gtk_css_provider_load_from_data (provider,
@@ -319,8 +302,6 @@ static void panel_menu_bar_class_init(PanelMenuBarClass* klass)
 	widget_class->parent_set = panel_menu_bar_parent_set;
 	widget_class->size_allocate = panel_menu_bar_size_allocate;
 
-	g_type_class_add_private(klass, sizeof(PanelMenuBarPrivate));
-
 	g_object_class_install_property(gobject_class, PROP_ORIENTATION, g_param_spec_enum("orientation", "Orientation", "The PanelMenuBar orientation", PANEL_TYPE_ORIENTATION, PANEL_ORIENTATION_TOP, G_PARAM_READWRITE));
 }
 
@@ -426,18 +407,11 @@ void panel_menu_bar_popup_menu(PanelMenuBar* menubar, guint32 activate_time)
 {
 	GtkMenu* menu;
 	GtkMenuShell* menu_shell;
-	GtkWidget* toplevel;
-	GdkWindow* window;
 
 	g_return_if_fail(PANEL_IS_MENU_BAR(menubar));
 
 	menu = GTK_MENU(menubar->priv->applications_menu);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (menubar));
-	menubar->priv->interrupted_window = panel_util_get_current_active_window (toplevel);
-	window = gtk_widget_get_window (toplevel);
-	panel_util_set_current_active_window (toplevel, GDK_WINDOW_XID(window));
-
 	/*
 	 * We need to call _gtk_menu_shell_activate() here as is done in
 	 * window_key_press_handler in gtkmenubar.c which pops up menu
