@@ -57,17 +57,8 @@
 #include "panel-util.h"
 #include "panel-schemas.h"
 
-#define BOOKMARKS_FILENAME      ".gtk-bookmarks"
 #define MAX_BOOKMARK_ITEMS      100
 
-G_DEFINE_TYPE(PanelPlaceMenuItem, panel_place_menu_item, GTK_TYPE_IMAGE_MENU_ITEM)
-G_DEFINE_TYPE(PanelDesktopMenuItem, panel_desktop_menu_item, GTK_TYPE_IMAGE_MENU_ITEM)
-
-#define PANEL_PLACE_MENU_ITEM_GET_PRIVATE(o) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((o), PANEL_TYPE_PLACE_MENU_ITEM, PanelPlaceMenuItemPrivate))
-#define PANEL_DESKTOP_MENU_ITEM_GET_PRIVATE(o) \
-	(G_TYPE_INSTANCE_GET_PRIVATE((o), PANEL_TYPE_DESKTOP_MENU_ITEM, PanelDesktopMenuItemPrivate))
-
 struct _PanelPlaceMenuItemPrivate {
 	GtkWidget   *menu;
 	PanelWidget *panel;
@@ -102,6 +93,9 @@ struct _PanelDesktopMenuItemPrivate {
 	guint        append_lock_logout : 1;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (PanelPlaceMenuItem, panel_place_menu_item, GTK_TYPE_IMAGE_MENU_ITEM)
+G_DEFINE_TYPE_WITH_PRIVATE (PanelDesktopMenuItem, panel_desktop_menu_item, GTK_TYPE_IMAGE_MENU_ITEM)
+
 static void activate_uri_on_screen(const char* uri, GdkScreen* screen)
 {
 	panel_show_uri(screen, uri, gtk_get_current_event_time(), NULL);
@@ -367,8 +361,8 @@ panel_place_menu_item_append_gtk_bookmarks (GtkWidget *menu, guint max_items_or_
 	GSList      *add_bookmarks, *l;
 	PanelBookmark *bookmark;
 
-	filename = g_build_filename (g_get_home_dir (),
-				     BOOKMARKS_FILENAME, NULL);
+	filename = g_build_filename (g_get_user_config_dir (),
+				     "gtk-3.0", "bookmarks", NULL);
 
 	io_channel = g_io_channel_new_file (filename, "r", NULL);
 	g_free (filename);
@@ -1130,7 +1124,7 @@ panel_place_menu_item_create_menu (PanelPlaceMenuItem *place_item)
 	GtkWidget *toplevel = gtk_widget_get_toplevel (places_menu);
 	GdkScreen *screen = gtk_widget_get_screen(GTK_WIDGET(toplevel));
 	GdkVisual *visual = gdk_screen_get_rgba_visual(screen);
-	gtk_widget_set_visual(GTK_WIDGET(toplevel), visual); 
+	gtk_widget_set_visual(GTK_WIDGET(toplevel), visual);
 
 	return places_menu;
 }
@@ -1353,7 +1347,7 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 	char  *bookmarks_filename;
 	GError *error;
 
-	menuitem->priv = PANEL_PLACE_MENU_ITEM_GET_PRIVATE (menuitem);
+	menuitem->priv = panel_place_menu_item_get_instance_private (menuitem);
 
 	if (mate_gsettings_schema_exists (CAJA_DESKTOP_SCHEMA)) {
 		menuitem->priv->caja_desktop_settings = g_settings_new (CAJA_DESKTOP_SCHEMA);
@@ -1387,8 +1381,8 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 
 	menuitem->priv->recent_manager = gtk_recent_manager_get_default ();
 
-	bookmarks_filename = g_build_filename (g_get_home_dir (),
-					       BOOKMARKS_FILENAME, NULL);
+	bookmarks_filename = g_build_filename (g_get_user_config_dir (),
+					       "gtk-3.0", "bookmarks", NULL);
 	bookmark = g_file_new_for_path (bookmarks_filename);
 
 	error = NULL;
@@ -1455,7 +1449,7 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 static void
 panel_desktop_menu_item_init (PanelDesktopMenuItem *menuitem)
 {
-	menuitem->priv = PANEL_DESKTOP_MENU_ITEM_GET_PRIVATE (menuitem);
+	menuitem->priv = panel_desktop_menu_item_get_instance_private (menuitem);
 }
 
 static void
@@ -1464,8 +1458,6 @@ panel_place_menu_item_class_init (PanelPlaceMenuItemClass *klass)
 	GObjectClass *gobject_class = (GObjectClass   *) klass;
 
 	gobject_class->finalize  = panel_place_menu_item_finalize;
-
-	g_type_class_add_private (klass, sizeof (PanelPlaceMenuItemPrivate));
 }
 
 static void
@@ -1474,8 +1466,6 @@ panel_desktop_menu_item_class_init (PanelDesktopMenuItemClass *klass)
 	GObjectClass *gobject_class = (GObjectClass   *) klass;
 
 	gobject_class->finalize  = panel_desktop_menu_item_finalize;
-
-	g_type_class_add_private (klass, sizeof (PanelDesktopMenuItemPrivate));
 }
 
 GtkWidget* panel_place_menu_item_new(gboolean use_image)
