@@ -31,7 +31,10 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
+
+#ifdef HAVE_X11
 #include <gdk/gdkx.h>
+#endif
 
 #include <libpanel-util/panel-list.h>
 #include <libmate-desktop/mate-dconf.h>
@@ -41,7 +44,7 @@
 #include "panel.h"
 #include "panel-widget.h"
 #include "panel-util.h"
-#include "panel-multiscreen.h"
+#include "panel-multimonitor.h"
 #include "panel-toplevel.h"
 #include "panel-lockdown.h"
 #include "panel-schemas.h"
@@ -571,10 +574,14 @@ panel_profile_queue_toplevel_location_change (PanelToplevel          *toplevel,
 
 	g_settings_delay (toplevel->queued_settings);
 
-	if (change->screen_changed)
+#ifdef HAVE_X11
+	if (change->screen_changed &&
+	    GDK_IS_X11_SCREEN (change->screen)) {
 		g_settings_set_int (toplevel->queued_settings,
 							"screen",
 							gdk_x11_screen_get_screen_number (change->screen));
+	}
+#endif
 
 	if (change->monitor_changed)
 		g_settings_set_int (toplevel->queued_settings,
@@ -909,7 +916,7 @@ panel_profile_find_empty_spot (GdkScreen *screen,
 	*monitor = 0;
 	*orientation = PANEL_ORIENTATION_TOP;
 
-	filled_spots = g_new0 (int, panel_multiscreen_monitors (screen));
+	filled_spots = g_new0 (int, panel_multimonitor_monitors ());
 
 	for (li = panel_toplevel_list_toplevels (); li != NULL; li = li->next) {
 		PanelToplevel *toplevel = li->data;
@@ -924,7 +931,7 @@ panel_profile_find_empty_spot (GdkScreen *screen,
 		filled_spots[toplevel_monitor] |= panel_toplevel_get_orientation (toplevel);
 	}
 
-	for (i = 0; i < panel_multiscreen_monitors (screen); i++) {
+	for (i = 0; i < panel_multimonitor_monitors (); i++) {
 		/* These are ordered based on "priority" of the
 		   orientation when picking it */
 		if ( ! (filled_spots[i] & PANEL_ORIENTATION_TOP)) {
@@ -963,6 +970,7 @@ panel_profile_create_toplevel (GdkScreen *screen)
 	PanelOrientation orientation;
 	int              monitor;
 	GSettings       *settings;
+	int              screen_number;
 
 	g_return_if_fail (screen != NULL);
 
@@ -973,7 +981,14 @@ panel_profile_create_toplevel (GdkScreen *screen)
 	settings = g_settings_new_with_path (PANEL_TOPLEVEL_SCHEMA, path);
 	g_free (path);
 
-	g_settings_set_int (settings, PANEL_TOPLEVEL_SCREEN_KEY, gdk_x11_screen_get_screen_number (screen));
+	screen_number = 0;
+#ifdef HAVE_X11
+	if (GDK_IS_X11_SCREEN (screen)) {
+		screen_number = gdk_x11_screen_get_screen_number (screen);
+	}
+#endif // HAVE_X11
+
+	g_settings_set_int (settings, PANEL_TOPLEVEL_SCREEN_KEY, screen_number);
 
 	if (panel_profile_find_empty_spot (screen, &orientation, &monitor)) {
 		g_settings_set_int (settings, PANEL_TOPLEVEL_MONITOR_KEY, monitor);
@@ -1029,16 +1044,6 @@ panel_profile_delete_toplevel (PanelToplevel *toplevel)
 
 	toplevel_id = panel_profile_get_toplevel_id (toplevel);
 
-	/* disable GSettings signals */
-	if (toplevel->settings) {
-		g_object_unref (toplevel->settings);
-		toplevel->settings = NULL;
-	}
-	if (toplevel->background_settings) {
-		g_object_unref (toplevel->background_settings);
-		toplevel->background_settings = NULL;
-	}
-
 	panel_profile_delete_toplevel_objects (toplevel_id);
 
 	panel_profile_remove_from_list (PANEL_GSETTINGS_TOPLEVELS, toplevel_id);
@@ -1445,6 +1450,18 @@ panel_profile_delete_removed_ids (PanelGSettingsKeyType    type,
 	g_slist_free (removed_ids);
 }
 
+static gboolean
+load_default_layout_idle (gpointer unused) {
+	if (g_slist_length (panel_toplevel_list_toplevels ()) != 0) {
+		/* some toplevels are not destroyed yet, waiting */
+		return TRUE;
+	}
+
+	/* load the default layout and stop this handler */
+	panel_profile_ensure_toplevel_per_screen ();
+	return FALSE;
+}
+
 static void
 panel_profile_toplevel_id_list_notify (GSettings *settings,
 									   gchar *key,
@@ -1487,7 +1504,7 @@ panel_profile_toplevel_id_list_notify (GSettings *settings,
 
 	/* if there are no panels, reset layout to default */
 	if (g_slist_length (toplevel_ids) == 0)
-		panel_profile_ensure_toplevel_per_screen ();
+		g_idle_add (load_default_layout_idle, NULL);
 
 	g_slist_free (existing_toplevels);
 	g_slist_free (toplevel_ids);
