@@ -22,11 +22,16 @@
  */
 
 #include <config.h>
+
+#ifndef HAVE_X11
+#error file should only be compiled when HAVE_X11 is enabled
+#endif
+
 #include <gdk/gdkx.h>
 
 #include "panel-struts.h"
 
-#include "panel-multiscreen.h"
+#include "panel-multimonitor.h"
 #include "panel-xutils.h"
 
 
@@ -68,17 +73,16 @@ panel_struts_find_strut (PanelToplevel *toplevel)
 }
 
 static void
-panel_struts_get_monitor_geometry (GdkScreen *screen,
-				   int        monitor,
+panel_struts_get_monitor_geometry (int        monitor,
 				   int       *x,
 				   int       *y,
 				   int       *width,
 				   int       *height)
 {
-        *x      = panel_multiscreen_x      (screen, monitor);
-        *y      = panel_multiscreen_y      (screen, monitor);
-        *width  = panel_multiscreen_width  (screen, monitor);
-        *height = panel_multiscreen_height (screen, monitor);
+        *x      = panel_multimonitor_x      (monitor);
+        *y      = panel_multimonitor_y      (monitor);
+        *width  = panel_multimonitor_width  (monitor);
+        *height = panel_multimonitor_height (monitor);
 }
 
 static PanelStrut *
@@ -201,7 +205,7 @@ panel_struts_allocate_struts (PanelToplevel *toplevel,
 		if (strut->screen != screen || strut->monitor != monitor)
 			continue;
 
-		panel_struts_get_monitor_geometry (strut->screen, strut->monitor,
+		panel_struts_get_monitor_geometry (strut->monitor,
 						   &monitor_x, &monitor_y,
 						   &monitor_width, &monitor_height);
 
@@ -256,9 +260,12 @@ panel_struts_set_window_hint (PanelToplevel *toplevel)
 	int         monitor_x, monitor_y, monitor_width, monitor_height;
 	int         screen_width, screen_height;
 	int         leftmost, rightmost, topmost, bottommost;
+	int         scale;
 
 	widget = GTK_WIDGET (toplevel);
 
+	g_return_if_fail (GDK_IS_X11_DISPLAY (gtk_widget_get_display (widget)));
+
 	if (!gtk_widget_get_realized (widget))
 		return;
 
@@ -267,24 +274,23 @@ panel_struts_set_window_hint (PanelToplevel *toplevel)
 		return;
 	}
 
+	scale = gtk_widget_get_scale_factor (widget);
 	strut_size = strut->allocated_strut_size;
 
-	screen_width  = WidthOfScreen (gdk_x11_screen_get_xscreen (strut->screen));
-	screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (strut->screen));
+	screen_width  = WidthOfScreen (gdk_x11_screen_get_xscreen (strut->screen)) / scale;
+	screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (strut->screen)) / scale;
 
-	panel_struts_get_monitor_geometry (strut->screen,
-					   strut->monitor,
+	panel_struts_get_monitor_geometry (strut->monitor,
 					   &monitor_x,
 					   &monitor_y,
 					   &monitor_width,
 					   &monitor_height);
 
-        panel_multiscreen_is_at_visible_extreme (strut->screen,
-                                                 strut->monitor,
-                                                 &leftmost,
-                                                 &rightmost,
-                                                 &topmost,
-                                                 &bottommost);
+        panel_multimonitor_is_at_visible_extreme (strut->monitor,
+                                                  &leftmost,
+                                                  &rightmost,
+                                                  &topmost,
+                                                  &bottommost);
 
 	switch (strut->orientation) {
 	case PANEL_ORIENTATION_TOP:
@@ -315,13 +321,15 @@ panel_struts_set_window_hint (PanelToplevel *toplevel)
 	panel_xutils_set_strut (gtk_widget_get_window (widget),
 				strut->orientation,
 				strut_size,
-				strut->allocated_strut_start,
-				strut->allocated_strut_end);
+				strut->allocated_strut_start * scale,
+				strut->allocated_strut_end * scale);
 }
 
 void
 panel_struts_unset_window_hint (PanelToplevel *toplevel)
 {
+	g_return_if_fail (GDK_IS_X11_DISPLAY (gtk_widget_get_display (GTK_WIDGET (toplevel))));
+
 	if (!gtk_widget_get_realized (GTK_WIDGET (toplevel)))
 		return;
 
@@ -411,6 +419,8 @@ panel_struts_register_strut (PanelToplevel    *toplevel,
 	gboolean    new_strut = FALSE;
 	int         monitor_x, monitor_y, monitor_width, monitor_height;
 
+	g_return_val_if_fail (GDK_IS_X11_DISPLAY (gtk_widget_get_display (GTK_WIDGET (toplevel))), FALSE);
+
 	if (!(strut = panel_struts_find_strut (toplevel))) {
 		strut = g_new0 (PanelStrut, 1);
 		new_strut = TRUE;
@@ -432,7 +442,7 @@ panel_struts_register_strut (PanelToplevel    *toplevel,
 	strut->strut_start = strut_start;
 	strut->strut_end   = strut_end;
 
-	panel_struts_get_monitor_geometry (screen, monitor,
+	panel_struts_get_monitor_geometry (monitor,
 					   &monitor_x, &monitor_y,
 					   &monitor_width, &monitor_height);
 
@@ -442,24 +452,32 @@ panel_struts_register_strut (PanelToplevel    *toplevel,
 		strut->geometry.y      = monitor_y;
 		strut->geometry.width  = strut->strut_end - strut->strut_start + 1;
 		strut->geometry.height = strut->strut_size / scale;
+		if (scale > 1)
+			strut->geometry.width -= (strut->strut_size / scale);
 		break;
 	case PANEL_ORIENTATION_BOTTOM:
 		strut->geometry.x      = strut->strut_start;
 		strut->geometry.y      = monitor_y + monitor_height - strut->strut_size;
 		strut->geometry.width  = strut->strut_end - strut->strut_start + 1;
 		strut->geometry.height = strut->strut_size / scale;
+		if (scale > 1)
+			strut->geometry.width -= (strut->strut_size / scale);
 		break;
 	case PANEL_ORIENTATION_LEFT:
 		strut->geometry.x      = monitor_x;
 		strut->geometry.y      = strut->strut_start;
 		strut->geometry.width  = strut->strut_size / scale;
 		strut->geometry.height = strut->strut_end - strut->strut_start + 1;
+		if (scale > 1)
+			strut->geometry.height -= (strut->strut_size / scale);
 		break;
 	case PANEL_ORIENTATION_RIGHT:
 		strut->geometry.x      = monitor_x + monitor_width - strut->strut_size;
 		strut->geometry.y      = strut->strut_start;
 		strut->geometry.width  = strut->strut_size / scale;
 		strut->geometry.height = strut->strut_end - strut->strut_start + 1;
+		if (scale > 1)
+			strut->geometry.height -= (strut->strut_size / scale);
 		break;
 	}
 
@@ -479,6 +497,8 @@ panel_struts_unregister_strut (PanelToplevel *toplevel)
 	GdkScreen  *screen;
 	int         monitor;
 
+	g_return_if_fail (GDK_IS_X11_DISPLAY (gtk_widget_get_display (GTK_WIDGET (toplevel))));
+
 	if (!(strut = panel_struts_find_strut (toplevel)))
 		return;
 
@@ -500,6 +520,7 @@ panel_struts_update_toplevel_geometry (PanelToplevel *toplevel,
 {
 	PanelStrut *strut;
 
+	g_return_val_if_fail (GDK_IS_X11_DISPLAY (gtk_widget_get_display (GTK_WIDGET (toplevel))), FALSE);
 	g_return_val_if_fail (x != NULL, FALSE);
 	g_return_val_if_fail (y != NULL, FALSE);
 
