@@ -28,6 +28,7 @@
 #include <glib/gstdio.h>
 #include <gio/gio.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gdk/gdkx.h>
 
 #define MATE_DESKTOP_USE_UNSTABLE_API
 #include <libmate-desktop/mate-desktop-utils.h>
@@ -39,7 +40,6 @@
 #include <libpanel-util/panel-xdg.h>
 
 #include "applet.h"
-#include "xstuff.h"
 #include "panel-config-global.h"
 #include "panel-schemas.h"
 #include "panel-globals.h"
@@ -1241,3 +1241,4 @@ panel_util_get_file_optional_homedir (const char *location)
 
 	return file;
 }
+
